Docker Compose file parsing and orchestration support.
This module provides types and functions for parsing Docker Compose files (docker-compose.yml / compose.yaml) and orchestrating multi-container deployments.
Structs
- Bind
Options - Bind mount options.
- Build
Config - Full build configuration.
- Compose
Config - Config definition (Swarm mode).
- Compose
Down Result - Result of a compose down operation
- Compose
Network - Network definition.
- Compose
RunResult - Result of a compose run operation
- Compose
Secret - Secret definition (Swarm mode).
- Compose
Service - Service definition in a Compose file.
- Compose
UpResult - Result of a compose up operation
- Compose
Volume - Volume definition.
- Depends
OnCondition - Depends on condition.
- Deploy
Config - Deploy configuration (Swarm mode).
- Device
Spec - Device specification.
- Health
Check - Health check configuration.
- Ipam
Config - IPAM configuration.
- Ipam
Pool Config - IPAM pool configuration.
- Logging
Config - Logging configuration.
- Placement
Config - Placement configuration.
- Port
Config - Full port configuration.
- Pyo3
Compose File - Represents a parsed Docker Compose file.
- Pyo3
Compose Project - Manages a Docker Compose project for orchestrating multi-container deployments.
- Resource
Config - Resource configuration.
- Resource
Spec - Resource specification.
- Restart
Policy Config - Restart policy configuration.
- Service
Config Config - Service config configuration.
- Service
Network Config - Service-specific network configuration.
- Service
Secret Config - Service secret configuration.
- Tmpfs
Options - tmpfs options.
- Update
Config - Update/rollback configuration.
- Volume
Mount Config - Full volume mount configuration.
- Volume
Options - Volume options.
Enums
- Compose
Build - Build configuration for a service.
- Depends
On - Depends on configuration.
- Environment
Vars - Environment variables - can be list or map.
- External
Ref - External resource reference.
- Labels
- Labels - can be list or map.
- Port
Mapping - Port mapping.
- Service
Config - Service config reference.
- Service
Networks - Service networks configuration.
- Service
Secret - Service secret reference.
- String
OrInt - String or integer.
- String
OrList - String or list of strings.
- Ulimit
- Ulimit configuration.
- Volume
Mount - Volume mount.
Functions
- compose
- parse_
compose_ file - Parse a Docker Compose file from a file path.
- parse_
compose_ string - Parse a Docker Compose file from a YAML string.