Docker Plugin management support.
This module provides types and functions for managing Docker plugins.
Structs
- Pyo3
Plugin - Represents an individual Docker plugin.
- Pyo3
Plugins - Interface for managing Docker plugins collection.
Docker Plugin management support.
This module provides types and functions for managing Docker plugins.