pub struct Pyo3Service { /* private fields */ }Expand description
Represents an individual Docker Swarm service.
Swarm mode must be enabled for these operations to work.
Implementations
Sourceimpl Pyo3Service
impl Pyo3Service
pub fn new(docker: Pyo3Docker, id: &str) -> Self
Sourcepub fn inspect(&self) -> PyResult<Py<PyAny>>
pub fn inspect(&self) -> PyResult<Py<PyAny>>
Inspect the service to get detailed information.
Returns: dict: Detailed service information including spec, endpoint, update status, etc.
Raises: SystemError: If the operation fails
Sourcepub fn delete(&self) -> PyResult<()>
pub fn delete(&self) -> PyResult<()>
Delete the service from the swarm.
Returns: None
Raises: SystemError: If the service cannot be deleted
Sourcepub fn logs(
&self,
stdout: Option<bool>,
stderr: Option<bool>,
timestamps: Option<bool>,
n_lines: Option<usize>,
all: Option<bool>,
since: Option<&Bound<'_, PyDateTime>>,
) -> String
pub fn logs( &self, stdout: Option<bool>, stderr: Option<bool>, timestamps: Option<bool>, n_lines: Option<usize>, all: Option<bool>, since: Option<&Bound<'_, PyDateTime>>, ) -> String
Get service logs.
Args: stdout: Include stdout stderr: Include stderr timestamps: Include timestamps n_lines: Number of lines to return from the end of logs all: Return all logs since: Only return logs since this datetime
Returns: str: Service logs