pub struct Pyo3Tasks { /* private fields */ }Expand description
Interface for managing Docker Swarm tasks collection.
Tasks are individual units of work running on swarm nodes as part of a service. Swarm mode must be enabled for these operations to work.
Implementations